@@ -197,9 +197,7 @@ class InstagramScraper(Scraper):
         self.output_datasets['profiles'] = self.output_datasets['profiles'].append(tmp_list_profiles, ignore_index=True)
         if 'posts' in self.output_datasets:
             for account in tmp_list_profiles:
-                print(account['twitter_internal_id'])
                 posts_data = self.query_posts(self.cookies, account['twitter_internal_id'])
-                print(list(posts_data))
                 tmp_list_posts.append(list(posts_data))
             self.output_datasets['posts'] = self.output_datasets['posts'].append(tmp_list_posts, ignore_index=True)
         if 'followers' in tmp_list_profiles:
